@@ -2,10 +2,9 @@ use strict;
 use warnings;
 package Dist::Zilla::App::Command::issues;
 # ABSTRACT: Print the count of outstanding RT and github issues for your distribution
-# vim: set ts=8 sw=4 tw=78 et :
-$Dist::Zilla::App::Command::issues::VERSION = '0.007';
+# vim: set ts=8 sts=4 sw=4 tw=78 et :
+our $VERSION = '0.008';
 use Dist::Zilla::App -command;
-use namespace::autoclean;
 
 sub abstract { "print your distribution's count of outstanding RT and github issues" }
 
@@ -63,7 +62,7 @@ Dist::Zilla::App::Command::issues - Print the count of outstanding RT and github
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
