@@ -1,16 +1,14 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::CheckIssues;
-# git description: v0.006-1-ge46957a
-$Dist::Zilla::Plugin::CheckIssues::VERSION = '0.007';
+package Dist::Zilla::Plugin::CheckIssues; # git description: v0.007-9-g7723491
 # ABSTRACT: Retrieve count of outstanding RT and github issues for your distribution
 # KEYWORDS: plugin bugs issues rt github
-# vim: set ts=8 sw=4 tw=78 et :
-
+# vim: set ts=8 sts=4 sw=4 tw=78 et :
+our $VERSION = '0.008';
 use Moose;
 with 'Dist::Zilla::Role::BeforeRelease';
 use List::Util 1.33 'none';
-use Term::ANSIColor 'colored';
+use Term::ANSIColor 3.00 'colored';
 use Encode ();
 use namespace::autoclean;
 
@@ -44,7 +42,7 @@ has repo_url => (
                 next if none { $plugin->isa('Dist::Zilla::Plugin::' . $_) }
                     qw(MetaResources AutoMetaResources GithubMeta GitHub::Meta Repository);
 
-                $self->log_debug('calling metadata for ' . $plugin->plugin_name);
+                $self->log_debug([ 'calling metadata for %s', $plugin->plugin_name ]);
                 my $plugin_meta = $plugin->metadata;
                 $url = (($plugin_meta->{resources} || {})->{repository} || {})->{url} || '';
                 last if $url;
@@ -63,7 +61,7 @@ has _github_owner_repo => (
 
         if (my $url = $self->repo_url)
         {
-            $self->log_debug('getting issue data for ' . $url . '...');
+            $self->log_debug([ 'getting issue data for %s...', $url ]);
             my ($owner_name, $repo_name) = $url =~ m{github\.com[:/]([^/]+)/([^/]+?)(?:/|\.git|$)};
             return [ $owner_name, $repo_name ] if $owner_name and $repo_name;
         }
@@ -209,7 +207,7 @@ Dist::Zilla::Plugin::CheckIssues - Retrieve count of outstanding RT and github i
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
